# Zbuilder: Building VMs and applying ansible playbooks

[![PyPi version](https://pypip.in/v/zbuilder/badge.png)](https://pypi.org/project/zbuilder/)
[![PyPi downloads](https://pypip.in/d/zbuilder/badge.png)](https://pypistats.org/packages/zbuilder)
[![Build status](https://github.com/hasiotis/zbuilder/workflows/Build%20status/badge.svg)](https://github.com/hasiotis/zbuilder/actions?query=workflow%3A%22Build+status%22)
[![Documentation Status](https://readthedocs.org/projects/zbuilder/badge/?version=develop)](https://zbuilder.readthedocs.io/en/develop/?badge=develop)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/hasiotis/zbuilder/blob/master/LICENSE)

ZBuilder is a tool to help you build VMs ready to be transfered to ansible.
By using ansible as a library, it has access to all ansible variables. This
way it achieves high integration with ansible.

## Installation

Install and update using:
```
pip3 install --user --upgrade zbuilder
```

## Links

* [Documentation](https://zbuilder.readthedocs.io/en/stable/?badge=stable)
* [Releases](https://pypi.org/project/zbuilder/)
* [Code](https://github.com/hasiotis/zbuilder)
